@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: css-text
 version: 0.1.2.1
-id: css-text-0.1.2.1-9e91a6e24ab9d04d01b694bbf376f115
-key: csste_4KSQSf83xgaFOGmAy34cfM
+id: css-text-0.1.2.1-44ac19493562c9a35faccdcd0341bb88
+key: csste_GN5R7HBkpbo5ozKPEwXixm
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -18,9 +18,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/css-text-0.1.2.1
-hs-libraries: HScss-text-0.1.2.1-4KSQSf83xgaFOGmAy34cfM
+hs-libraries: HScss-text-0.1.2.1-GN5R7HBkpbo5ozKPEwXixm
 depends:
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
 haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
